#ifndef __GDCA__H__
#define __GDCA__H__

#ifdef __cplusplus
extern "C" {
#endif

#define GDCA_VERSION  "1.1.0"

#define CERT_NAME_MAX_SIZE 512   //证书名字长度
#define CERT_DEFAULT_INSTALL_PATH  "/etc/pki/GDCA/" //默认证书安装路径

/*错误码*/
#define GDCA_OK             0X0    /*成功*/

/*基本错误码*/
#define GDCA_MEMORY_ERR           0x00000001  /*内存申请错误*/
#define GDCA_NOT_FILE_ERR         0x00000002  /*文件不存在*/
#define GDCA_OPEN_FILE_ERR        0x00000003  /*打开文件失败*/
#define GDCA_PARAMETERS_EMPT_ERR  0x00000004  /*传入参数为空错误失败*/
#define GDCA_NAME_LEN_ERR         0x00000005  /*证书名字长度错误*/
#define GDCA_INSTALL_PATH_LEN_ERR 0x00000006  /*证书安装路径长度错误*/
#define GDCA_DELETE_FILE_ERR      0x00000007  /*要删除的证书不存在*/


/*证书相关错误码*/
#define GDCA_CERT_BASE                 0x00010000
#define GDCA_CERT_OPEN_ERR             GDCA_CERT_BASE + 0x00000001  /*x509打开证书失败*/
#define GDCA_CERT_LOAD_ERR             GDCA_CERT_BASE + 0x00000002  /*加载证书内容失败*/
#define GDCA_CERT_VERIFY_ERR           GDCA_CERT_BASE + 0X00000003  /*证书签名验签错误*/
#define GDCA_CERT_OWNER_ERR            GDCA_CERT_BASE + 0X00000004  /*证书发行者错误*/
#define GDCA_CERT_VALIDITY_DATE_ERR    GDCA_CERT_BASE + 0X00000005  /*证书有效期错误*/


/*post请求相关错误*/
#define GDCA_POST_BASE                  0x00020000
#define GDCA_POST_EASY_PRTFORM_ERR      GDCA_POST_BASE + 0x00000001 /*执行post请求错误*/
#define GDCA_POST_RESPONSE_NODATA_ERR   GDCA_POST_BASE + 0x00000002 /*返回响应数据包含证书信息为空*/

typedef enum {
	CERT_IMPORT_SUCCESSFUL,  /*证书导入成功*/
	CERT_OVERLAY_IMPORT      /*覆盖导入*/
} IMPORT_STATUS;

typedef enum {
	CERT_NEWEST,    /*已是最新的，未作更新*/
	CERT_UPDATED,    /*已进行更新*/
	CERT_NOTFOUND   /*指定更新的证书不属于国电CA证书*/
} UPDATA_STATUS;

//本地已安装的证书信息
typedef struct GDCA_CERT_st {
	char file_name[CERT_NAME_MAX_SIZE];  //证书名字
}kdk_gdca_cert;

//证书更新状态
typedef struct GDCA_UPDATA_STATUS_st {
	char file_name[CERT_NAME_MAX_SIZE];  //证书名字
	int updata_status;  //更新状态
}kdk_gdca_updata_status;

/**
 *功能：更新系统下国家电子CA根证书
 *参数:
 *      cert_name[in] 进行更新的证书名字，当传入NULL时，进行全部更新
 *      update_status[out] 证书更新状态
 *      cert_num[out] 证书更新状态记录的证书数量
 *      install_path[in] 安装路径,默认/etc/pki/GDCA/
 *返回值：0 成功，非0失败
 **/
int kdk_gdca_update(const char *cert_name, kdk_gdca_updata_status **updata_status, int *cert_num, char *install_path=(char *)CERT_DEFAULT_INSTALL_PATH);

/**
 *功能：查询系统下国家电子CA根证书支持情况
 *参数：
 *      gdca_info[in] 已安装证书的信息
 *      number[in]    已安装证书数量
 *      install_path[in] 安装路径,默认/etc/pki/GDCA/
 *返回值：0 成功，非0失败
 * */
int kdk_gdca_exist(kdk_gdca_cert **gdca_info, int *number,char *install_path=(char *)CERT_DEFAULT_INSTALL_PATH);

/**
 *函数功能：导入国家电子CA根证书
 *参数：source_path[in]  待导入证书路径
 *      dest_path[in]   证书导入路径,默认/etc/pki/GDCA/
 *返回值：0成功， 非0失败
 **/
int kdk_gdca_import(const char *source_path, char *dest_path=(char *)CERT_DEFAULT_INSTALL_PATH);

/**
 *函数功能：删除部署的国家电子CA根证书
 *参数：file_name[in] 要删除的证书名字
 *      dest_path[in] 证书部署路径,默认/etc/pki/GDCA/
 *返回值：0成功， 非0失败
 **/
int kdk_gdca_delete(const char *file_name,char *dest_path=(char *)CERT_DEFAULT_INSTALL_PATH);

#ifdef __cplusplus
}
#endif

#endif
